utils

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 31, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DirExists

func DirExists(path string) (bool, error)

DirExists checks if a directory exists at the given path. Returns (true, nil) if the directory exists, (false, nil) if it does not exist, or (false, err) if an error other than "not exist" occurs.

func FileExists

func FileExists(path string) (bool, error)

FileExists checks if a file exists at the given path. Returns (true, nil) if the file exists, (false, nil) if it does not exist, or (false, err) if an error other than "not exist" occurs.

func Hash

func Hash(s string) string

StringID returns a stable hash for a given string. Same input always produces the same ID.

Types

This section is empty.

Jump to