Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DirExists ¶
DirExists checks if a directory exists at the given path. Returns (true, nil) if the directory exists, (false, nil) if it does not exist, or (false, err) if an error other than "not exist" occurs.
func FileExists ¶
FileExists checks if a file exists at the given path. Returns (true, nil) if the file exists, (false, nil) if it does not exist, or (false, err) if an error other than "not exist" occurs.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.